pub trait URCodable { }Expand description
A type that can be encoded to and decoded from a UR.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait URCodable { }A type that can be encoded to and decoded from a UR.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".